![alt tag](https://raw.github.com/dogfalo/materialize/master/images/materialize.gif)
===========

[![Gitter](https://badges.gitter.im/Join Chat.svg)](https://gitter.im/Dogfalo/materialize?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge)
Materialize, a CSS Framework based on material design

### Current Version : v0.97.2

## Sass Requirements:
- Ruby Sass 3.3+, LibSass 0.6+

## Supported Browsers:
Chrome 35+, Firefox 31+, Safari 7+, IE 10+

## Changelog
- v0.97.2 (Nov 8, 2015)
  - Image support inside select
  - Optgroup supported in select
  - Multiple select added
  - Card styling fixes
  - Breadcrumbs added
  - Scrollable tabs
  - Tooltips and dropdowns position themselves more intelligently inside the window
  - FAB menu is click-toggleable
  - Horizontal FAB support added
- v0.97.1 (Sep 13, 2015)
  - Added new range slider with uses noUiSlider to provide powerful options
  - Added CSS for Chips
  - Toasts support adding of html elements
  - Fixed select destroy/creation bug
  - Bugfixes for dropdown, badges, collections, scrollfire
  - Added default preloader color variable
  - File input now supports multiple files and dynamically loaded elements
- v0.97.0 (June 21, 2015)
  - **Documentation changed to use Official Google Icon web font**
  - **Input errors added**
  - Flicker on Firefox on dropdowns fixed
  - Pagination made more responsive
  - Modal now prevents scrolling
  - Modal animation added
  - Support for multiple modals added
  - Programmatic control of FAB to open/close added
  - Programmatic control of slider to play/pause added
  - Plus many more bug fixes
- v0.96.1 (April 6, 2015)
  - Dropdown Fixes
  - Materialize functions fixed for Meteor
- v0.96.0 (April 1, 2015)
  - **Toasts, transitions, scrollfire added under Materialize namespace**
  - **Dropdown is now created as a child of its parent**
  - Collapsibles supports nesting
  - Modal Bottom Sheet added
  - Indeterminate Checkboxes added
  - New Checkbox Style Added
  - Text Inputs supports placeholder/readonly
  - Google Inbox-like Collapsible added
  - Text Character Counter added
  - Waves no longer breaks on SVG's

- v0.95.3 (Feb 25, 2015)
  - Parallax image loading / responsiveness fixes
  - Date picker supports month/year as dropdown
  - Dismissable collection items
  - Avatar collection items
  - Pagination Added
  - ScrollFire fixes


## Contributing
[Please read CONTRIBUTING.md for more information](CONTRIBUTING.md)
